--[[
DR TRACKER function list:
- Should show Diminishing Returns.
- Diminishing Return has a 15 Seconds duration AFTER the spell FADES.
- The first DR has full duration, the second 50%, the last 25%.
- It needs to get UnitDebuffs, when the Debuff is applied.
- It needs to store this data until the Debuff fades.
- Then the DR must be set to 15 Seconds.
]]--
local maxDebuffs = 40;
local diminishingReturn = 15;


function ArenaLive_DrTracker_Initialise (self, parent, icons)

	if ( not self ) then
		return;
	end
	
	if ( parent ) then
		parent.drTracker = self;
	end
	
	local numIcons = 0;
	
	-- Register all drIcons
	for key, value in pairs(icons) do
		numIcons = numIcons + 1;
		self["icon"..numIcons] = value;
		
	end
	
	self.numIcons = numIcons;
	self.auraTable = {};
	
	self:RegisterEvent("UNIT_AURA");
end

function ArenaLive_DrTracker_UpdateUnit (self, unit)
	self.unit = unit;
	self:SetScript("OnEvent", ArenaLive_DrTracker_OnEvent);
	self:Show();
end

function ArenaLive_DrTracker_ResetFrame (self)
	self.unit = nil;
	self:SetScript("OnEvent", nil);
	self:Hide();
end

function ArenaLive_DrTracker_OnEvent(self, event, ...)

	local unit = select(1, ...);
	
	if ( not unit == self.unit ) then
		return;
	end
	
	if ( event == "UNIT_AURA" ) then
		ArenaLive_DrTracker_Update(self);
	end

end

function ArenaLive_DrTracker_OnHide(self)
	local i = 1;
	
	while i <= self.numIcons do
		-- TODO: Icon reset
	end
end

function ArenaLive_DrTracker_Update(self)

	if ( not self.unit ) then
		return;
	end

	for i = 1, maxDebuffs do
		
		-- Through expires and spellID we will create a relatively unique identifier for the spell.
		local _, _, icon, _, _, _, expires, _, _, _, spellID = UnitDebuff(self.unit, i);
		local currentDebuffIdentifier, currentTableDebuffIdentifier, currentDebuffspellID;
		
		if ( spellID ) and ( not self.auraTable[i] )  then
			-- Hurray, a new debuff.
		elseif ( spellID ) and ( self.auraTable[i] )
		-- The debuff exists already.
			if ( caster ) then
				currentDebuffIdentifier = expires..spellID;
			end
			
			currentTableDebuffIdentifier = self.auraTable[i]["identifier"];
			
			if ( currentDebuffIdentifier == currentTableDebuffIdentifier ) then
				-- Still the same buff. So we leave it alone.
			else
				
			end
		
		elseif ( not spellID ) and ( self.auraTable[i] ) then
			--[[ The Buff doesn't exist anymore, but was listed in our table. The only reason for this is that it has expired.
			Otherwise the first part of the if-query would have changed its entry to a new key.]]--
		else
			-- Nothing to do here.
			break;
		end

end