local addonName, L = ...;
function ALUF_ArenaEnemyFrames_OnLoad (self)
	
	self:RegisterEvent("PLAYER_ENTERING_WORLD");
	self:RegisterEvent("ARENA_PREP_OPPONENT_SPECIALIZATIONS");
	
end

function ALUF_ArenaEnemyFrames_OnEvent (self, event, ...)

	if ( event == "ARENA_PREP_OPPONENT_SPECIALIZATIONS" ) then
		
			if ( not InCombatLockdown() ) then
				local opponents = GetNumArenaOpponentSpecs();
				if ( opponents > 0 ) then
					for i = 1, 5 do
						
					local frame = _G["ALUF_ArenaEnemyFrame"..i];
					local id = frame:GetID();
					
						if ( id <= opponents ) then
							UnregisterUnitWatch(frame);
							frame:Show();
						else
							frame:Hide();
						end
						
						
					end
				end
			end
		
	elseif ( event == "PLAYER_ENTERING_WORLD" ) then
		if ( not InCombatLockdown() and ARENALIVE_DATABASE[addonName]["frameTypes"]["arenaFrames"]["isLocked"] ) then
			
			local _, instanceType = IsInInstance();
			

			if ( instanceType ~= "arena") then
				for i = 1, 5 do
					local frame = _G["ALUF_ArenaEnemyFrame"..i];
					RegisterUnitWatch(frame);
				end	
			else
				local opponents = GetNumArenaOpponentSpecs();
				
				if ( opponents > 0 ) then
					for i = 1, 5 do
						
						local frame = _G["ALUF_ArenaEnemyFrame"..i];
						local id = frame:GetID();
					
						if ( id <= opponents ) then
							UnregisterUnitWatch(frame);
							frame:Show();
						else
							frame:Hide();
						end
						
						
					end
				end				
			end
		end
	end

end
function ALUF_ArenaEnemyFrame_OnLoad (self)
	
	local id = self:GetID();
	local prefix = self:GetName();
	local unit = "arena"..id;
	local numCastHistoryIcons = ARENALIVE_DATABASE["ArenaLiveUnitFrames"]["frameTypes"]["arenaFrames"]["castHistory"]["shownIcons"];
	
	ArenaLive_SecureUnitButton_OnLoad(self, unit, nil, true, true)
	
	ArenaLive_UnitFrame_Initialise(self, addonName, "arenaFrames", _G[prefix.."Background"], _G[prefix.."Border"], _G[prefix.."Name"], _G[prefix.."Portrait"], _G[prefix.."3DPortrait"], _G[prefix.."PortraitOverlay"], _G[prefix.."HealthBar"], _G[prefix.."HealthBarText"], _G[prefix.."PowerBar"], _G[prefix.."PowerBarText"], nil, nil, _G[prefix.."HealPredictionBar"], _G[prefix.."AbsorbBar"], _G[prefix.."AbsorbBarOverlay"], _G[prefix.."AbsorbFullHPIndicator"], _G[prefix.."TargetIndicator"]);
	ArenaLive_UnitFrame_UpdateUnit(self, unit);
	
	ArenaLive_Icon_Initialise(_G[prefix.."Icon1"], addonName, "arenaFrames", 1, _G[prefix.."Icon1Texture"], _G[prefix.."Icon1Cooldown"]);
	ArenaLive_Icon_UpdateUnit(_G[prefix.."Icon1"], unit);
	ArenaLive_Icon_Initialise(_G[prefix.."Icon2"], addonName, "arenaFrames", 2, _G[prefix.."Icon2Texture"], _G[prefix.."Icon2Cooldown"]);
	ArenaLive_Icon_UpdateUnit(_G[prefix.."Icon2"], unit);
	ArenaLive_Icon_Initialise(_G[prefix.."Icon3"], addonName, "arenaFrames", 3, _G[prefix.."Icon3Texture"], _G[prefix.."Icon3Cooldown"], self);
	ArenaLive_Icon_UpdateUnit(_G[prefix.."Icon3"], unit);
	
	ArenaLive_CastBar_Initialise(_G[prefix.."CastBar"], addonName, "arenaFrames", _G[prefix.."CastBarBorder"], _G[prefix.."CastBarBorderShieldGlow"], _G[prefix.."CastBarIcon"], _G[prefix.."CastBarText"], _G[prefix.."CastBarAnimationGroup"], _G[prefix.."CastBarAnimationGroupFadeOutAnimation"], false, true);
	ArenaLive_CastHistory_Initialise(_G[prefix.."CastHistory"], addonName, "arenaFrames", numCastHistoryIcons, "ArenaLive_CastHistoryIconTemplate", "left");
	
	self:RegisterEvent("ARENA_OPPONENT_UPDATE");
	self:RegisterEvent("UNIT_NAME_UPDATE");
	self:RegisterEvent("ARENA_PREP_OPPONENT_SPECIALIZATIONS");
	self:RegisterEvent("PLAYER_ENTERING_WORLD");

	ALUF_ArenaEnemyFrame_AdjustAttachments(self);	
end



function ALUF_ArenaEnemyFrame_OnEvent (self, event, ...)
	
	ArenaLive_UnitFrame_OnEvent(self, event, ...)
	local id = self:GetID();
	local prefix = self:GetName();
	local arg1, arg2 = ...;
	
	if ( event == "ARENA_OPPONENT_UPDATE" ) then
		
		if (arg1 ~= self.unit ) then
			return;
		end
		
		if ( arg2 == "seen" or arg2 == "destroyed") then
			ALUF_ArenaEnemyFrame_Unlock(self);
			ALUF_ArenaEnemyFrame_Update(self);
		elseif ( arg2 == "unseen" ) then
			ALUF_ArenaEnemyFrame_Lock(self);
		elseif ( arg2 == "cleared" ) then
			ALUF_ArenaEnemyFrame_Unlock(self);
			ALUF_ArenaEnemyFrame_Update(self);
		end
	
	elseif ( event == "ARENA_PREP_OPPONENT_SPECIALIZATIONS" ) then
		local numOpps = GetNumArenaOpponentSpecs();
		
		if (id <= numOpps ) then
			ArenaLive_Icon_Update(self.icon1);
			ArenaLive_Icon_Update(self.icon2);
			ArenaLive_Icon_Update(self.icon3);
			ArenaLive_UnitFrame_PortraitUpdate(self);
			ArenaLive_CastHistory_ResetAllIcons(self.castHistory);
		end
	elseif ( event == "UNIT_NAME_UPDATE" ) then
		ALUF_ArenaEnemyFrame_Update(self);
	end

end
function ALUF_ArenaEnemyFrame_Update(self)
	
	if ( not self.unit ) then
		return;
	end
	
	if (UnitExists(self.unit) ) then
		ArenaLive_UnitFrame_Update(self);
		ArenaLive_Icon_Update(self.icon1);
		ArenaLive_Icon_Update(self.icon2);
		ArenaLive_Icon_Update(self.icon3);
		ArenaLive_CastBar_OnEvent(self.castBar, "PLAYER_ENTERING_WORLD", nil);
		ArenaLive_PortraitOverlay_QueryAuras(self, self.unit);
	end

end

function ALUF_ArenaEnemyFrame_OnShow(self)
		if ( not self.unit ) then
			return;
		end

		ArenaLive_Icon_Update(self.icon3);
		ArenaLive_UnitFrame_PortraitUpdate(self);
end

function ALUF_ArenaEnemyFrame_Lock (self)
	self.healthBar:SetStatusBarColor(0.5, 0.5, 0.5);
	self.healthBar.lockColor = true;
	self.healthBar.lockValues = true;
	self.powerBar:SetStatusBarColor(0.5, 0.5, 0.5);
	self.powerBar.lockColor = true;
	self.powerBar.lockValues = true;
end

function ALUF_ArenaEnemyFrame_Unlock (self)
	self.healthBar.lockColor = false;
	self.powerBar.lockColor = false;
	self.healthBar.lockValues = false;
	self.powerBar.lockValues = false;
end

function ALUF_ArenaEnemyFrame_AdjustAttachments (self)
	
	local id = self:GetID();
	local unit = "arena"..id;
	local castBarIsShown, castBarPosition, castHistoryIsShown, castHistoryPosition, drTrackerIsShown, drTrackerPosition;
	
	if ( self.castBar ) then
		castBarIsShown = ARENALIVE_DATABASE[addonName]["frameTypes"][self.frameType]["castBar"]["isShown"];
		castBarPosition = ARENALIVE_DATABASE[addonName]["frameTypes"][self.frameType]["castBar"]["position"];
	end

	if ( self.castHistory ) then
		castHistoryIsShown = ARENALIVE_DATABASE[addonName]["frameTypes"][self.frameType]["castHistory"]["isShown"];
		castHistoryPosition = ARENALIVE_DATABASE[addonName]["frameTypes"][self.frameType]["castHistory"]["position"];
	end	
	
	if ( self.drTracker ) then
		drTrackerIsShown = ARENALIVE_DATABASE[addonName]["frameTypes"][self.frameType]["drTracker"]["isShown"];
		drTrackerPosition = ARENALIVE_DATABASE[addonName]["frameTypes"][self.frameType]["drTracker"]["position"];
	end	
	
	if ( castBarIsShown ) then
		ArenaLive_CastBar_UpdateUnit(self.castBar, unit);
		
		self.castBar:ClearAllPoints();
		
		if ( castBarPosition == "LEFT" ) then
			self.castBar:SetPoint("TOPRIGHT", self, "TOPLEFT", -25, -14)
		elseif ( castBarPosition == "RIGHT" ) then
			self.castBar:SetPoint("TOPLEFT", self, "TOPRIGHT", 25, -14)
		end
	else
		ArenaLive_CastBar_ResetFrame(self.castbar);
	end
	
	if ( castHistoryIsShown and castBarIsShown ) then
		-- We only show castHistory in combination with castBar at the moment.
		ArenaLive_CastHistory_UpdateUnit(self.castHistory, unit);
	else
		ArenaLive_CastHistory_ResetFrame(self.castHistory)
	end
end


function ALUF_ArenaEnemyFrame_AdjustFramePosition (self)

	local growUpwards = ARENALIVE_DATABASE[addonName]["frameTypes"][self.frameType]["growUpwards"];
	local frameSpacing = ARENALIVE_DATABASE[addonName]["frameTypes"][self.frameType]["frameSpacing"];
	local point, relativeTo, relativePoint, xOffset, yOffset = self:GetPoint();
	self:ClearAllPoints();
	
	if ( growUpwards ) then
		self:SetPoint("BOTTOMRIGHT", relativeTo, "TOPRIGHT", xOffset, frameSpacing);
	else
		self:SetPoint("TOPRIGHT", relativeTo, "BOTTOMRIGHT", xOffset, -frameSpacing);
	end
	
	

end