local addonName, L = ...;

function ALUF_OptionsToTFrame_OnLoad(self)
	-- Create a sub panel in ArenaLiveUnitFrame addon panel
	self.name= L["totFrame"];
	self.okay = ALUF_OptionsToTFrame_Okay;
	self.cancel = ALUF_OptionsToTFrame_Cancel;
	self.parent = "ArenaLiveUnitFrames";
	InterfaceOptions_AddCategory(self);	

	-- Set Localisation:
	ALUF_ToTFrame_OptionsTitle:SetText(L["ALUFToTFrameTitle"]);
	
	self:RegisterEvent("ADDON_LOADED");
end

function ALUF_OptionsToTFrame_Initialise(self)
	local prefix = self:GetName();
	local checkbutton, editbox, slider, dropdown, selectedValue;
	
	-- Initialise Checkbuttons
	checkbutton = _G[prefix.."IsEnabled"];
	ALUF_Options_CheckButtonInitialise(checkbutton, "enableFrame", "targetOfTargetFrame", nil, "enabled");
	
	checkbutton = _G[prefix.."IsLocked"];
	ALUF_Options_CheckButtonInitialise(checkbutton, "lockFrame", "targetOfTargetFrame", nil, "isLocked");
	
	checkbutton = nil;
	
	
	-- Initialise Editboxes
	
	-- Initialise Sliders
	slider = _G[prefix.."FrameScale"];
	slider.valueFactor = 0.1;
	ALUF_Options_SliderInitialise(slider, "frameScale", "targetOfTargetFrame", nil, "scale")
	
	-- Initialise DropDown menus	
	dropdown = _G[prefix.."HealthBarColour"];
	selectedValue = ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["healthBarColourMode"];	
	UIDropDownMenu_Initialize(dropdown, ALUF_Options_DropDownInitialise);
	UIDropDownMenu_SetSelectedValue(dropdown, selectedValue, false);

	dropdown = _G[prefix.."NameColour"];
	selectedValue = ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["nameColourMode"];	
	UIDropDownMenu_Initialize(dropdown, ALUF_Options_DropDownInitialise);
	UIDropDownMenu_SetSelectedValue(dropdown, selectedValue, false);
	
	dropdown = nil;
	ArenaLive_FrameMover_UpdateVisible(ALUF_TargetofTargetFrameMover);
end

function ALUF_OptionsToTFrame_OnEvent(self, event, ...)
	local arg1 = ...;
	
	if ( event == "ADDON_LOADED" and arg1 == addonName ) then
		ALUF_OptionsToTFrame_Initialise(self)
	end

end

function ALUF_OptionsToTFrame_OnShow(self)
	local prefix = self:GetName();
	local isEnabledCheckbutton = _G[prefix.."IsEnabled"];
	local framelockCheckbutton = _G[prefix.."IsLocked"];
	local frameScale = _G[prefix.."FrameScale"];
	if ( InCombatLockdown() ) then
		isEnabledCheckbutton:Disable();
		framelockCheckbutton:Disable();
		frameScale:Disable();
		ArenaLive_SystemMessage(L["inCombatLockdown"]);
	else
		isEnabledCheckbutton:Enable();
		framelockCheckbutton:Enable();
		frameScale:Enable();
	end
end


function ALUF_OptionsToTFrame_Okay(self)
	local prefix = self:GetName();
	local frame;
	
	if ( not InCombatLockdown() ) then
		-- CHECKBUTTONS
		frame = _G[prefix.."IsEnabled"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["enabled"] = frame:GetChecked();
		
		frame = _G[prefix.."IsLocked"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["isLocked"] = frame:GetChecked();
		
		
		-- EDITBOXES
		
		-- SLIDERS
		frame = _G[prefix.."FrameScale"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["scale"] = ALUF_Options_SliderGetValue(frame);
		
		
		-- DROPDOWN MENUS		
		frame = _G[prefix.."HealthBarColour"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["healthBarColourMode"] = UIDropDownMenu_GetSelectedValue(frame);
		
		frame = _G[prefix.."NameColour"];
		ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["nameColourMode"] = UIDropDownMenu_GetSelectedValue(frame);

		frame = nil;
		
		-- Updapte the frame and saved variables
		ArenaLive_Database_UpdateSavedVariables(addonName, ArenaLiveUnitFrames_SavedVariables);
		
		local scale = ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["scale"];
		ALUF_TargetofTargetFrame:SetScale(scale);
		ArenaLive_FrameMover_UpdateVisible(ALUF_TargetofTargetFrameMover);
		ArenaLive_UnitFrame_Update(ALUF_TargetofTargetFrame);
	else
		ALUF_OptionsToTFrame_Cancel(self)
	end
end



function ALUF_OptionsToTFrame_Cancel(self)
	
	local prefix = self:GetName();
	local frame;
	
	-- CHECKBUTTONS
	frame = _G[prefix.."IsEnabled"];
	frame:SetChecked(ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["enabled"]);
	
	frame = _G[prefix.."IsLocked"];
	frame:SetChecked(ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["isLocked"]);
	
	-- EDITBOXES
	
	-- SLIDERS	
	frame = _G[prefix.."FrameScale"];
	ALUF_Options_SliderSetValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["scale"]);
	
	
	-- DROPDOWN MENUS	
	frame = _G[prefix.."HealthBarColour"];
	UIDropDownMenu_SetSelectedValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["healthBarColourMode"]);
	
	frame = _G[prefix.."NameColour"];
	UIDropDownMenu_SetSelectedValue(ARENALIVE_DATABASE[addonName]["frameTypes"]["targetOfTargetFrame"]["nameColourMode"]);

	frame = nil;
end